# SPDX-FileCopyrightText: 2024-present Trenton H <rda0128ou@mozmail.com>
#
# SPDX-License-Identifier: MPL-2.0
from typing import Final

from simpleiso3166.generated.types import CountryCodeAlpha2Type

COUNTRY_ALIAS_TO_CODE: Final[dict[str, CountryCodeAlpha2Type]] = {
    # United Kingdom variations
    "England": "GB",
    "Great Britain": "GB",
    "UK": "GB",
    "U.K.": "GB",
    "United Kingdom of Great Britain and Northern Ireland": "GB",
    "Britain": "GB",
    "Northern Ireland": "GB",
    "Scotland": "GB",
    "Wales": "GB",
    # United States variations
    "America": "US",
    "USA": "US",
    "U.S.A.": "US",
    "U.S.": "US",
    "United States": "US",
    "United States of America": "US",
    "The States": "US",
    "Uncle Sam": "US",
    # Korea variations
    "Republic of Korea": "KR",
    "South Korea": "KR",
    "ROK": "KR",
    "North Korea": "KP",
    "Democratic People's Republic of Korea": "KP",
    "DPRK": "KP",
    # Netherlands variations
    "Holland": "NL",
    "The Netherlands": "NL",
    "Kingdom of the Netherlands": "NL",
    "Nederland": "NL",
    # China variations
    "PRC": "CN",
    "People's Republic of China": "CN",
    "Mainland China": "CN",
    "Communist China": "CN",
    # Taiwan variations
    "Chinese Taipei": "TW",
    "Republic of China": "TW",
    "Taiwan ROC": "TW",
    # Russia variations
    "Russian Federation": "RU",
    "Russia": "RU",
    # European countries
    "Czech Republic": "CZ",
    "Czechia": "CZ",
    "Eire": "IE",
    "Republic of Ireland": "IE",
    "Éire": "IE",
    "Suomi": "FI",
    "Sverige": "SE",
    "Norge": "NO",
    "Danmark": "DK",
    "Hellas": "GR",
    "Polska": "PL",
    "Magyarország": "HU",
    "Österreich": "AT",
    "Schweiz": "CH",
    "España": "ES",
    "België": "BE",
    "Belgique": "BE",
    "Belgien": "BE",
    # Middle East variations
    "UAE": "AE",
    "The Emirates": "AE",
    "United Arab Emirates": "AE",
    "Palestine": "PS",
    "State of Palestine": "PS",
    "Palestinian Territories": "PS",
    "KSA": "SA",
    "Saudi": "SA",
    # Asian countries
    "Myanmar": "MM",
    "Burma": "MM",
    "Brunei": "BN",
    "Macau": "MO",
    "Macao": "MO",
    "Vietnam": "VN",
    "Viet Nam": "VN",
    "Laos": "LA",
    "Lao People's Democratic Republic": "LA",
    "East Timor": "TL",
    "Timor-Leste": "TL",
    "Nippon": "JP",
    "Nihon": "JP",
    "Bharat": "IN",
    "Hindustan": "IN",
    # African countries
    "Congo-Kinshasa": "CD",
    "DR Congo": "CD",
    "DRC": "CD",
    "Congo Republic": "CG",
    "Congo-Brazzaville": "CG",
    "Ivory Coast": "CI",
    "Cote d'Ivoire": "CI",
    "Swaziland": "SZ",
    "Eswatini": "SZ",
    "Cape Verde": "CV",
    "Cabo Verde": "CV",
    "Guinea-Bissau": "GW",
    "Bissau": "GW",
    "Rhodesia": "ZW",
    "Dahomey": "BJ",
    "Upper Volta": "BF",
    "Tanganyika": "TZ",
    "Zanzibar": "TZ",
    "Tanzania": "TZ",
    # Australia/Oceania
    "Down Under": "AU",
    "New Zealand": "NZ",
    "Aotearoa": "NZ",
    "PNG": "PG",
    # North America
    "Dominican": "DO",
    "T&T": "TT",
    "Tobago": "TT",
    "Trinidad": "TT",
    # South America
    "Brasil": "BR",
    "Argentine": "AR",
    "Argentine Republic": "AR",
    "British Guiana": "GY",
    "Guyana": "GY",
    "Surinam": "SR",
    "Venezuela": "VE",
    "Bolivarian Republic of Venezuela": "VE",
    # Historical names that may still be used colloquially
    "Persia": "IR",
    "Siam": "TH",
    "Formosa": "TW",
    "Ceylon": "LK",
    "Kampuchea": "KH",
    "Malaya": "MY",
    "Abyssinia": "ET",
    # Variations with "The" prefix
    "The Bahamas": "BS",
    "The Gambia": "GM",
    "The Philippines": "PH",
    "The Sudan": "SD",
    "The Ukraine": "UA",
    "The Czech Republic": "CZ",
    "The United Arab Emirates": "AE",
    "The Dominican Republic": "DO",
    "The Congo": "CD",
    # Common misspellings
    "Philipines": "PH",
    "Columbia": "CO",
    "Lybia": "LY",
    "Kazakstan": "KZ",
    "Turkmenistan": "TM",
    "Uzbekistan": "UZ",
    "Kyrgystan": "KG",
    "Tajikistan": "TJ",
    "Azerbajan": "AZ",
    "Belorussia": "BY",
    "Moldavia": "MD",
    # Names in other languages
    "Deutschland": "DE",
    "Allemagne": "DE",
    "Alemania": "DE",
    "Niemcy": "DE",
    "Francia": "FR",
    "Frankreich": "FR",
    "Ranska": "FR",
    "Italie": "IT",
    "Italien": "IT",
    "Italia": "IT",
    "Japón": "JP",
    "Japon": "JP",
    "Japonya": "JP",
    "Chine": "CN",
    "China": "CN",
    "Xina": "CN",
    "Zhongguo": "CN",
}
